[−][src]Enum druid_shell::error::Error
Error codes. At the moment, this is little more than HRESULT, but that might change.
Variants
Other(&'static str)Hr(HRESULT)A function is available on newer version of windows.