ApplicationExt

Trait ApplicationExt 

pub trait ApplicationExt {
    // Required methods
    fn hide(&self);
    fn hide_others(&self);
    fn set_menu(&self, menu: Menu);
}
macOS specific extensions to Application

Required Methods

fn hide(&self)

Hide the application this window belongs to. (cmd+H)

fn hide_others(&self)

Hide all other applications. (cmd+opt+H)

fn set_menu(&self, menu: Menu)

Sets the global application menu, on platforms where there is one.

On platforms with no global application menu, this has no effect.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors