FileSpec

Struct FileSpec 

pub struct FileSpec {
    pub name: &'static str,
    pub extensions: &'static [&'static str],
}
A description of a filetype, for specifying allowed types in a file dialog.

Windows

Each instance of this type is converted to a COMDLG_FILTERSPEC struct.

macOS

These file types also apply to directories to define them as packages.

Fields

name: &'static str

A human readable name, describing this filetype.

This is used in the Windows file dialog, where the user can select from a dropdown the type of file they would like to choose.

This should not include the file extensions; they will be added automatically. For instance, if we are describing Word documents, the name would be “Word Document”, and the displayed string would be “Word Document (*.doc)”.

extensions: &'static [&'static str]

The file extensions used by this file type.

This should not include the leading ‘.’.

Implementations

Source

impl FileSpec

pub const TEXT: FileSpec

pub const JPG: FileSpec

pub const GIF: FileSpec

pub const PNG: FileSpec

pub const PDF: FileSpec

pub const HTML: FileSpec

pub const fn new( name: &'static str, extensions: &'static [&'static str], ) -> Self

Create a new FileSpec.

Examples found in repository?
examples/shello.rs (line 55)
47    fn command(&mut self, id: u32) {
48        match id {
49            0x100 => {
50                self.handle.close();
51                Application::global().quit()
52            }
53            0x101 => {
54                let options = FileDialogOptions::new().show_hidden().allowed_types(vec![
55                    FileSpec::new("Rust Files", &["rs", "toml"]),
56                    FileSpec::TEXT,
57                    FileSpec::JPG,
58                ]);
59                self.handle.open_file(options);
60            }
61            0x102 => {
62                let options = FileDialogOptions::new().show_hidden().allowed_types(vec![
63                    FileSpec::new("Rust Files", &["rs", "toml"]),
64                    FileSpec::TEXT,
65                    FileSpec::JPG,
66                ]);
67                self.handle.save_as(options);
68            }
69            _ => println!("unexpected id {id}"),
70        }
71    }