[][src]Struct druid_shell::IdleHandle

pub struct IdleHandle(_);

A handle that can enqueue tasks on the window loop.

Implementations

impl IdleHandle[src]

pub fn add_idle<F>(&self, callback: F) where
    F: FnOnce(&dyn Any) + Send + 'static, 
[src]

Add an idle handler, which is called (once) when the message loop is empty. The idle handler will be run from the main UI thread, and won't be scheduled if the associated view has been dropped.

Note: the name "idle" suggests that it will be scheduled with a lower priority than other UI events, but that's not necessarily the case.

pub fn schedule_idle(&mut self, token: IdleToken)[src]

Request a callback from the runloop. Your WinHander::idle method will be called with the token that was passed in.