KeyEvent

Struct KeyEvent 

#[non_exhaustive]
pub struct KeyEvent { pub state: KeyState, pub key: KbKey, pub code: Code, pub location: Location, pub mods: Modifiers, pub repeat: bool, pub is_composing: bool, }
Information about a keyboard event.

Note that this type is similar to KeyboardEvent in keyboard-types, but has a few small differences for convenience.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: KeyState

Whether the key is pressed or released.

key: KbKey

Logical key value.

code: Code

Physical key position.

location: Location

Location for keys with multiple instances on common keyboards.

mods: Modifiers

Flags for pressed modifier keys.

repeat: bool

True if the key is currently auto-repeated.

is_composing: bool

Events with this flag should be ignored in a text editor and instead composition events should be used.