Modifiers

Struct Modifiers 

pub struct Modifiers(/* private fields */);
The modifiers.

This type is a thin wrappers around keyboard_types::Modifiers, mostly for the convenience methods. If those get upstreamed, it will simply become that type.

Implementations

Source

impl Modifiers

pub const ALT: Modifiers

pub const ALT_GRAPH: Modifiers

pub const CAPS_LOCK: Modifiers

pub const CONTROL: Modifiers

pub const FN: Modifiers

pub const FN_LOCK: Modifiers

pub const META: Modifiers

pub const NUM_LOCK: Modifiers

pub const SCROLL_LOCK: Modifiers

pub const SHIFT: Modifiers

pub const SYMBOL: Modifiers

pub const SYMBOL_LOCK: Modifiers

pub const HYPER: Modifiers

pub const SUPER: Modifiers

pub fn raw(&self) -> Modifiers

Get the inner value.

Note that this function might go away if our changes are upstreamed.

pub fn shift(&self) -> bool

Determine whether Shift is set.

pub fn ctrl(&self) -> bool

Determine whether Ctrl is set.

pub fn alt(&self) -> bool

Determine whether Alt is set.

pub fn meta(&self) -> bool

Determine whether Meta is set.

pub fn empty() -> Modifiers

Returns an empty set of modifiers.

pub fn is_empty(&self) -> bool

Returns true if no modifiers are set.

pub fn contains(&self, other: Modifiers) -> bool

Returns true if all the modifiers in other are set.

pub fn set(&mut self, other: Modifiers, value: bool)

Inserts or removes the specified modifiers depending on the passed value.