MouseButtons

Struct MouseButtons 

pub struct MouseButtons(/* private fields */);
A set of MouseButtons.

Implementations

Source

impl MouseButtons

pub fn new() -> MouseButtons

Create a new empty set.

pub fn insert(&mut self, button: MouseButton)

Add the button to the set.

pub fn remove(&mut self, button: MouseButton)

Remove the button from the set.

pub fn with(self, button: MouseButton) -> MouseButtons

Builder-style method for adding the button to the set.

pub fn without(self, button: MouseButton) -> MouseButtons

Builder-style method for removing the button from the set.

pub fn contains(self, button: MouseButton) -> bool

Returns true if the button is in the set.

pub fn is_empty(self) -> bool

Returns true if the set is empty.

pub fn is_superset(self, buttons: MouseButtons) -> bool

Returns true if all the buttons are in the set.

pub fn has_left(self) -> bool

Returns true if MouseButton::Left is in the set.

pub fn has_right(self) -> bool

Returns true if MouseButton::Right is in the set.

pub fn has_middle(self) -> bool

Returns true if MouseButton::Middle is in the set.

pub fn has_x1(self) -> bool

Returns true if MouseButton::X1 is in the set.

pub fn has_x2(self) -> bool

Returns true if MouseButton::X2 is in the set.

pub fn extend(&mut self, buttons: MouseButtons)

Adds all the buttons to the set.

pub fn union(self, other: MouseButtons) -> MouseButtons

Returns a union of the values in self and other.

pub fn clear(&mut self)

Clear the set.

pub fn count(self) -> u32

Count the number of pressed buttons in the set.