[][src]Struct druid_shell::window::WindowHandle

pub struct WindowHandle {
    pub inner: WindowHandle,
}

Fields

inner: WindowHandle

Methods from Deref<Target = WindowHandle>

pub fn show(&self)[src]

pub fn close(&self)[src]

pub fn invalidate(&self)[src]

pub fn set_title(&self, title: &str)[src]

Set the title for this menu.

pub fn set_menu(&self, menu: Menu)[src]

pub fn show_context_menu(&self, menu: Menu, x: f64, y: f64)[src]

pub fn get_hwnd(&self) -> Option<HWND>[src]

Get the raw HWND handle, for uses that are not wrapped in druid_win_shell.

pub fn file_dialog(
    &self,
    ty: FileDialogType,
    options: FileDialogOptions
) -> Result<OsString, Error>
[src]

Deprecated since 0.3.0:

use methods on WinCtx instead

Open a modal file dialog.

Note: this method will be reworked to avoid reentrancy problems. Currently, calling it may result in important messages being dropped.

pub fn get_idle_handle(&self) -> Option<IdleHandle>[src]

Get a handle that can be used to schedule an idle task.

pub fn get_dpi(&self) -> f32[src]

Get the dpi of the window.

pub fn px_to_pixels(&self, x: f32) -> i32[src]

Convert a dimension in px units to physical pixels (rounding).

pub fn px_to_pixels_xy(&self, x: f32, y: f32) -> (i32, i32)[src]

Convert a point in px units to physical pixels (rounding).

pub fn pixels_to_px<T: Into<f64>>(&self, x: T) -> f32[src]

Convert a dimension in physical pixels to px units.

pub fn pixels_to_px_xy<T: Into<f64>>(&self, x: T, y: T) -> (f32, f32)[src]

Convert a point in physical pixels to px units.