[][src]Enum druid_shell::windows::PresentStrategy

pub enum PresentStrategy {
    Hwnd,
    Sequential,
    Flip,
    FlipRedirect,
}

It's very tricky to get smooth dynamics (especially resizing) and good performance on Windows. This setting lets clients experiment with different strategies.

Variants

Hwnd

Don't try to use DXGI at all, only create Hwnd render targets. Note: on Windows 7 this is the only mode available.

Sequential

Corresponds to the swap effect DXGI_SWAP_EFFECT_SEQUENTIAL. In testing, it causes diagonal banding artifacts with Nvidia adapters, and incremental present doesn't work. However, it is compatible with GDI (such as menus).

Flip

Corresponds to the swap effect DXGI_SWAP_EFFECT_FLIP_SEQUENTIAL. In testing, it seems to perform well (including allowing smooth resizing when the frame can be rendered quickly), but isn't compatible with GDI.

FlipRedirect

Corresponds to the swap effect DXGI_SWAP_EFFECT_FLIP_SEQUENTIAL but with a redirection surface for GDI compatibility. Resize is very laggy and artifacty.