[][src]Struct druid_shell::windows::paint::PaintCtx

pub struct PaintCtx<'a> { /* fields omitted */ }

Context for painting by app into window.

Methods

impl<'a> PaintCtx<'a>[src]

pub fn d2d_factory(&self) -> &Factory[src]

Return the raw Direct2D factory for this painting context. Note: it's possible this will be wrapped to make it easier to port.

pub fn render_target(&mut self) -> &mut GenericRenderTarget[src]

Return the raw Direct2D RenderTarget for this painting context. Note: it's possible this will be wrapped to make it easier to port.