pub trait ApplicationExt {
// Required methods
fn hide(&self);
fn hide_others(&self);
fn set_menu(&self, menu: Menu);
}Expand description
macOS specific extensions to Application
Required Methods
Sourcefn hide_others(&self)
fn hide_others(&self)
Hide all other applications. (cmd+opt+H)
Sets the global application menu, on platforms where there is one.
On platforms with no global application menu, this has no effect.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".