[−][src]Struct druid_shell::MouseButtons
A set of MouseButtons.
Implementations
impl MouseButtons[src]
pub fn new() -> MouseButtons[src]
Create a new empty set.
pub fn insert(&mut self, button: MouseButton)[src]
Add the button to the set.
pub fn remove(&mut self, button: MouseButton)[src]
Remove the button from the set.
pub fn with(self, button: MouseButton) -> MouseButtons[src]
Builder-style method for adding the button to the set.
pub fn without(self, button: MouseButton) -> MouseButtons[src]
Builder-style method for removing the button from the set.
pub fn contains(self, button: MouseButton) -> bool[src]
Returns true if the button is in the set.
pub fn is_empty(self) -> bool[src]
Returns true if the set is empty.
pub fn is_superset(self, buttons: MouseButtons) -> bool[src]
Returns true if all the buttons are in the set.
pub fn has_left(self) -> bool[src]
Returns true if MouseButton::Left is in the set.
pub fn has_right(self) -> bool[src]
Returns true if MouseButton::Right is in the set.
pub fn has_middle(self) -> bool[src]
Returns true if MouseButton::Middle is in the set.
pub fn has_x1(self) -> bool[src]
Returns true if MouseButton::X1 is in the set.
pub fn has_x2(self) -> bool[src]
Returns true if MouseButton::X2 is in the set.
pub fn extend(&mut self, buttons: MouseButtons)[src]
Adds all the buttons to the set.
pub fn union(self, other: MouseButtons) -> MouseButtons[src]
Returns a union of the values in self and other.
pub fn clear(&mut self)[src]
Clear the set.