[−][src]Struct druid_shell::windows::menu::Menu
A menu object, which can be either a top-level menubar or a submenu.
Methods
impl Menu[src]
pub fn new() -> Menu[src]
Create a new menu for a window.
pub fn new_for_popup() -> Menu[src]
Create a new popup (context / right-click) menu.
pub fn into_hmenu(self) -> HMENU[src]
pub fn add_dropdown(&mut self, menu: Menu, text: &str, enabled: bool)[src]
Add a dropdown menu. This takes the menu by ownership, but we'll probably want to change that so we can manipulate it later.
The text field has all the fun behavior of winapi CreateMenu.
pub fn add_item(
&mut self,
id: u32,
text: &str,
_key: Option<&HotKey>,
enabled: bool,
selected: bool
)[src]
&mut self,
id: u32,
text: &str,
_key: Option<&HotKey>,
enabled: bool,
selected: bool
)
Add an item to the menu.
pub fn add_separator(&mut self)[src]
Add a separator to the menu.